@@ -15,7 +15,7 @@ class GeneralAsyncIoRedis:
     async def get_async_redis_conn(self, **kwargs):
         return await aioredis.create_redis_pool((kwargs.get('redis_host'), kwargs.get('redis_port')), encoding='utf-8',
                                                 db=kwargs.get('redis_db'), password=kwargs.get('redis_pwd'),
-                                                loop=asyncio.get_event_loop())
+                                                loop=asyncio.get_running_loop())
 
     async def aio_redis_conn_close(self):
         if self.aio_redis_conn:
